@@ -263,9 +263,7 @@
    )
   (parser-generator-process-grammar)
   (parser-generator-ll-generate-table)
-
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '((b 1 . 2) (b 2 . 3) (a 3 . 4)))
             (string-length (length string))
@@ -278,8 +276,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should
@@ -288,8 +285,7 @@
     (parser-generator-ll-parse)))
   (message "Passed example 5.16 p. 352")
 
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '((b 1 . 2) (b 2 . 3)))
             (string-length (length string))
@@ -302,8 +298,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should-error
@@ -326,9 +321,7 @@
    )
   (parser-generator-process-grammar)
   (parser-generator-ll-generate-table)
-
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '((a 1 . 2) (b 2 . 3) (a 3 . 4) (a 4 . 5)))
             (string-length (length string))
@@ -341,8 +334,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should
@@ -367,9 +359,7 @@
    )
   (parser-generator-process-grammar)
   (parser-generator-ll-generate-table)
-
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '((a 1 . 2) (b 2 . 3) (b 3 . 4) (a 4 . 5) (b 5 . 6)))
             (string-length (length string))
@@ -382,8 +372,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should
@@ -411,9 +400,7 @@
    )
   (parser-generator-process-grammar)
   (parser-generator-ll-generate-table)
-
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '(("(" 1 . 2) ("a" 2 . 3) ("*" 3 . 4) ("a" 4 . 5) (")" 5 . 6)))
             (string-length (length string))
@@ -426,8 +413,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should
@@ -453,9 +439,7 @@
    )
   (parser-generator-process-grammar)
   (parser-generator-ll-generate-table)
-
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '(("(" 1 . 2) ("a" 2 . 3) ("+" 3 . 4) ("a" 4 . 5) (")" 5 . 6)))
             (string-length (length string))
@@ -468,8 +452,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should
@@ -478,8 +461,7 @@
     (parser-generator-ll-parse)))
   (message "Passed example from Wikipedia")
 
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '(("(" 1 . 2) ("a" 2 . 3) ("+" 3 . 4) ("a" 4 . 5)))
             (string-length (length string))
@@ -492,8 +474,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should-error
@@ -529,8 +510,7 @@
   (parser-generator-process-grammar)
   (parser-generator-ll-generate-table)
 
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '((b 1 . 2) (b 2 . 3) (a 3 . 4)))
             (string-length (length string))
@@ -543,8 +523,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should
@@ -553,8 +532,7 @@
     (parser-generator-ll-translate)))
   (message "Passed translation test 1")
 
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '((b 1 . 2) (b 2 . 3) (b 3 . 4) (a 4 . 5)))
             (string-length (length string))
@@ -595,9 +573,7 @@
    )
   (parser-generator-process-grammar)
   (parser-generator-ll-generate-table)
-
-  (setq
-   parser-generator-lex-analyzer--function
+  (parser-generator-lex-analyzer-set-function
    (lambda (index _state)
      (let* ((string '((a 1 . 2) (b 2 . 3) (b 3 . 4) (a 4 . 5) (b 5 . 6)))
             (string-length (length string))
@@ -610,8 +586,7 @@
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
 
-  (setq
-   parser-generator-lex-analyzer--get-function
+  (parser-generator-lex-analyzer-set-get-function
    (lambda (token)
      (car token)))
   (should
